@@ -8,7 +8,7 @@ from d3graph.d3graph import (
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '2.3.1'
+__version__ = '2.3.2'
 
 # import jinja2
 # if version.parse(jinja2.__version__) > version.parse("2.11.3"):
@@ -47,4 +47,11 @@ Examples
 >>> # Plot
 >>> d3.show()
 
+References
+----------
+* D3Graph: https://towardsdatascience.com/creating-beautiful-stand-alone-interactive-d3-charts-with-python-804117cb95a7
+* D3Blocks: https://towardsdatascience.com/d3blocks-the-python-library-to-create-interactive-and-standalone-d3js-charts-3dda98ce97d4
+* Github : https://github.com/erdogant/d3graph
+* Documentation: https://erdogant.github.io/d3graph/
+
 """
